==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorKeyPhoneAllOfSettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AllowedForEnum;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AuthenticatorKeyPhoneAllOfSettings
 */
@JsonPropertyOrder({ AuthenticatorKeyPhoneAllOfSettings.JSON_PROPERTY_ALLOWED_FOR })
@JsonTypeName("AuthenticatorKeyPhone_allOf_settings")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorKeyPhoneAllOfSettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALLOWED_FOR = "allowedFor";
    private AllowedForEnum allowedFor;

    public AuthenticatorKeyPhoneAllOfSettings() {
    }

    public AuthenticatorKeyPhoneAllOfSettings allowedFor(AllowedForEnum allowedFor) {

        this.allowedFor = allowedFor;
        return this;
    }

    /**
     * Get allowedFor
     *
     * @return allowedFor
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOWED_FOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AllowedForEnum getAllowedFor() {
        return allowedFor;
    }

    @JsonProperty(JSON_PROPERTY_ALLOWED_FOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllowedFor(AllowedForEnum allowedFor) {
        this.allowedFor = allowedFor;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorKeyPhoneAllOfSettings authenticatorKeyPhoneAllOfSettings = (AuthenticatorKeyPhoneAllOfSettings) o;
        return Objects.equals(this.allowedFor, authenticatorKeyPhoneAllOfSettings.allowedFor);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allowedFor);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorKeyPhoneAllOfSettings {\n");
        sb.append("    allowedFor: ").append(toIndentedString(allowedFor)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorKeyPhoneAllOfSettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AllowedForEnum;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AuthenticatorKeyPhoneAllOfSettings
 */
@JsonPropertyOrder({ AuthenticatorKeyPhoneAllOfSettings.JSON_PROPERTY_ALLOWED_FOR })
@JsonTypeName("AuthenticatorKeyPhone_allOf_settings")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorKeyPhoneAllOfSettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALLOWED_FOR = "allowedFor";
    private AllowedForEnum allowedFor;

    public AuthenticatorKeyPhoneAllOfSettings() {
    }

    public AuthenticatorKeyPhoneAllOfSettings allowedFor(AllowedForEnum allowedFor) {

        this.allowedFor = allowedFor;
        return this;
    }

    /**
     * Get allowedFor
     *
     * @return allowedFor
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOWED_FOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AllowedForEnum getAllowedFor() {
        return allowedFor;
    }

    @JsonProperty(JSON_PROPERTY_ALLOWED_FOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllowedFor(AllowedForEnum allowedFor) {
        this.allowedFor = allowedFor;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorKeyPhoneAllOfSettings authenticatorKeyPhoneAllOfSettings = (AuthenticatorKeyPhoneAllOfSettings) o;
        return Objects.equals(this.allowedFor, authenticatorKeyPhoneAllOfSettings.allowedFor);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allowedFor);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorKeyPhoneAllOfSettings {\n");
        sb.append("    allowedFor: ").append(toIndentedString(allowedFor)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
